import { Docker } from '../service/index.js';
import { Request } from '../util/index.js';
class ContainerRoutes {
    register(app) {
        app.post('/container/:containerName', async (req, res) => {
            try {
                const params = Request.getAllParams(req);
                const response = await Docker.create(params);
                res.status(201).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/container/status/:containerName?', async (req, res) => {
            try {
                const params = Request.getAllParams(req);
                const response = await Docker.statusContainer(params);
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/container/:type/:containerName?', async (req, res) => {
            try {
                const params = Request.getAllParams(req);
                const response = await Docker.info({
                    containerName: 'all',
                    ...params,
                });
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.put('/container/:type/:containerName', async (req, res) => {
            try {
                const params = Request.getAllParams(req);
                const response = await Docker.modify(params);
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.delete('/container/:containerName?', async (req, res) => {
            try {
                const params = Request.getAllParams(req);
                const response = await Docker.remove(params);
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
    }
}
export default new ContainerRoutes();
