import { Prisma } from '../db/index.js';
import { Gzip } from '../util/index.js';
class ProductSettingService {
    encodeConfig(config = {}) {
        return Gzip.encode(JSON.stringify(config, null, 2));
    }
    async create(params) {
        const { devopsId, config } = params;
        const data = {
            devopsId: Number(devopsId),
            config: this.encodeConfig(config) || '',
        };
        return Prisma.productSetting.create({ data });
    }
    async list(options) {
        const { decodeGZip = true, } = options || {};
        const data = await Prisma.productSetting.findMany({
            include: { product: true },
        });
        return data.map(({ config, product }) => {
            const configValue = decodeGZip ? JSON.parse(Gzip.decode(config)) : config;
            return ({
                config: configValue,
                devopsId: product.devopsId,
                productName: product.productName,
            });
        });
    }
    async remove({ devopsId, productsToRemove }) {
        const products = Array.isArray(productsToRemove) ? productsToRemove : [];
        const where = { devopsId: { in: products.map(Number) } };
        if (devopsId) {
            const response = await Prisma.productSetting.deleteMany({
                where: { devopsId: Number(devopsId) },
            });
            return response;
        }
        if (Array.isArray(productsToRemove)) {
            const response = Prisma.productSetting.deleteMany({ where });
            return response;
        }
    }
    async modify(params) {
        const { devopsId, config } = params;
        const response = await Prisma.productSetting.update({
            where: { devopsId: Number(devopsId) },
            data: { config: this.encodeConfig(config) || '' },
        });
        return response;
    }
    async getSettingForApi() {
        const productSetting = await this.list({ decodeGZip: false });
        return productSetting;
    }
}
export default new ProductSettingService();
