import axios from 'axios';
class Request {
    async send(url, options) {
        try {
            const response = await axios({ url, ...options });
            return response.data;
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    removeStartEndBar(text) {
        return text.replace(/^\/|\/+$/g, '');
    }
    buildUrl(url, { queryParams, endPoint }) {
        let newUrl = this.removeStartEndBar(url);
        if (endPoint)
            newUrl = `${newUrl}/${this.removeStartEndBar(endPoint)}`;
        if (queryParams && !!Object.keys(queryParams).length) {
            newUrl = `${newUrl}?${this.getQueryParams(queryParams)}`;
        }
        return newUrl;
    }
    getQueryParams(data = {}) {
        const searchParams = new URLSearchParams(Object.entries(data));
        return searchParams.toString();
    }
    async post(url, data = {}, options = {}) {
        return this.send(url, { ...options, data, method: 'POST' });
    }
    async get(url, queryParams = {}, options = {}) {
        const encodedUrl = this.buildUrl(url, { queryParams });
        return this.send(encodedUrl, { ...options, method: 'GET' });
    }
    async put(url, data = {}, options = {}) {
        return this.send(url, { ...options, data, method: 'PUT' });
    }
    async delete(url, data = {}, options = {}) {
        return this.send(url, { ...options, data, method: 'DELETE' });
    }
    getAllParams(request) {
        return { ...request.params, ...request.body, ...request.query };
    }
    handleResponseError(response, error) {
        if (error instanceof Error) {
            response.status(500).send({ error: error.message });
        }
        else {
            response.status(500).send({ error: 'UNEXPECTED_ERROR' });
        }
    }
}
export default new Request();
